pub struct ParserOptions {
pub lang: Option<String>,
pub source_type: Option<String>,
pub ast_type: Option<String>,
pub range: Option<bool>,
pub tokens: Option<bool>,
pub preserve_parens: Option<bool>,
pub show_semantic_errors: Option<bool>,
}Fields
lang: Option<String>Treat the source text as js, jsx, ts, tsx or dts.
source_type: Option<String>Treat the source text as script or module code.
ast_type: Option<String>Return an AST which includes TypeScript-related properties, or excludes them.
'js' is default for JS / JSX files.
'ts' is default for TS / TSX files.
The type of the file is determined from lang option, or extension of provided filename.
range: Option<bool>Controls whether the range property is included on AST nodes.
The range property is a [number, number] which indicates the start/end offsets
of the node in the file contents.
@default false
tokens: Option<bool>Controls whether parser should return tokens.
This option is not stable yet, and only available with experimental raw transfer.
@default false
preserve_parens: Option<bool>Emit ParenthesizedExpression and TSParenthesizedType in AST.
If this option is true, parenthesized expressions are represented by
(non-standard) ParenthesizedExpression and TSParenthesizedType nodes that
have a single expression property containing the expression inside parentheses.
@default true
show_semantic_errors: Option<bool>Produce semantic errors with an additional AST pass. Semantic errors depend on symbols and scopes, where the parser does not construct. This adds a small performance overhead.
@default false