pub struct ParserOptions {
pub source_type: Option<String>,
pub lang: Option<String>,
pub ast_type: Option<String>,
pub preserve_parens: Option<bool>,
pub show_semantic_errors: Option<bool>,
}Fields
source_type: Option<String>lang: Option<String>Treat the source text as js, jsx, ts, or tsx.
ast_type: Option<String>Return an AST which includes TypeScript-related properties, or excludes them.
'js' is default for JS / JSX files.
'ts' is default for TS / TSX files.
The type of the file is determined from lang option, or extension of provided filename.
preserve_parens: Option<bool>Emit ParenthesizedExpression in AST.
If this option is true, parenthesized expressions are represented by
(non-standard) ParenthesizedExpression nodes that have a single expression property
containing the expression inside parentheses.
@default true
show_semantic_errors: Option<bool>Produce semantic errors with an additional AST pass. Semantic errors depend on symbols and scopes, where the parser does not construct. This adds a small performance overhead.
@default false